.. _cmd:

Command line reference
======================

``datalad-osf`` has two main commands: ``datalad osf-credentials`` for OSF authentication management, and ``datalad create-sibling-osf`` for interactions with the OSF.
Find out more about each command below.

.. toctree::
   :maxdepth: 1

   generated/man/datalad-create-sibling-osf
   generated/man/datalad-osf-credentials
